"""
    XBIM Flex API v2

    This is the XBIM Flex Swagger service where you can explore the REST API for the platform.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: info@xbim.net
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from xbim_flex.aim.api_client import ApiClient, Endpoint as _Endpoint
from xbim_flex.aim.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)


class WexbimApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.wexbim_get_complete_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'oauth2'
                ],
                'endpoint_path': "/{region}/aim/2.0/{tenantId}/wexbim/complete",
                'operation_id': 'wexbim_get_complete',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'asset_id',
                    'model_id',
                    'tenant_id',
                    'region',
                ],
                'required': [
                    'asset_id',
                    'model_id',
                    'tenant_id',
                    'region',
                ],
                'nullable': [
                ],
                'enum': [
                    'region',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('region',): {

                        "UK": "UK",
                        "WESTEUROPE": "WestEurope",
                        "SANDBOX": "Sandbox"
                    },
                },
                'openapi_types': {
                    'asset_id':
                        (int,),
                    'model_id':
                        (int,),
                    'tenant_id':
                        (str,),
                    'region':
                        (str,),
                },
                'attribute_map': {
                    'asset_id': 'assetId',
                    'model_id': 'modelId',
                    'tenant_id': 'tenantId',
                    'region': 'region',
                },
                'location_map': {
                    'asset_id': 'query',
                    'model_id': 'query',
                    'tenant_id': 'path',
                    'region': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/octet-stream'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.wexbim_get_components_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'oauth2'
                ],
                'endpoint_path': "/{region}/aim/2.0/{tenantId}/wexbim/components",
                'operation_id': 'wexbim_get_components',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'asset_id',
                    'model_id',
                    'tenant_id',
                    'region',
                ],
                'required': [
                    'asset_id',
                    'model_id',
                    'tenant_id',
                    'region',
                ],
                'nullable': [
                ],
                'enum': [
                    'region',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('region',): {

                        "UK": "UK",
                        "WESTEUROPE": "WestEurope",
                        "SANDBOX": "Sandbox"
                    },
                },
                'openapi_types': {
                    'asset_id':
                        (int,),
                    'model_id':
                        (int,),
                    'tenant_id':
                        (str,),
                    'region':
                        (str,),
                },
                'attribute_map': {
                    'asset_id': 'assetId',
                    'model_id': 'modelId',
                    'tenant_id': 'tenantId',
                    'region': 'region',
                },
                'location_map': {
                    'asset_id': 'query',
                    'model_id': 'query',
                    'tenant_id': 'path',
                    'region': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/octet-stream'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.wexbim_get_dynamic_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'oauth2'
                ],
                'endpoint_path': "/{region}/aim/2.0/{tenantId}/wexbim/dynamic",
                'operation_id': 'wexbim_get_dynamic',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'asset_id',
                    'model_id',
                    'included',
                    'tenant_id',
                    'region',
                    'excluded',
                ],
                'required': [
                    'asset_id',
                    'model_id',
                    'included',
                    'tenant_id',
                    'region',
                ],
                'nullable': [
                ],
                'enum': [
                    'included',
                    'region',
                    'excluded',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('included',): {

                        "PRODUCT": "Product",
                        "ELEMENT": "Element",
                        "DISTRIBUTIONELEMENT": "DistributionElement",
                        "DISTRIBUTIONFLOWELEMENT": "DistributionFlowElement",
                        "DISTRIBUTIONCHAMBERELEMENT": "DistributionChamberElement",
                        "ENERGYCONVERSIONDEVICE": "EnergyConversionDevice",
                        "AIRTOAIRHEATRECOVERY": "AirToAirHeatRecovery",
                        "BOILER": "Boiler",
                        "BURNER": "Burner",
                        "CHILLER": "Chiller",
                        "COIL": "Coil",
                        "CONDENSER": "Condenser",
                        "COOLEDBEAM": "CooledBeam",
                        "COOLINGTOWER": "CoolingTower",
                        "ENGINE": "Engine",
                        "EVAPORATIVECOOLER": "EvaporativeCooler",
                        "EVAPORATOR": "Evaporator",
                        "HEATEXCHANGER": "HeatExchanger",
                        "HUMIDIFIER": "Humidifier",
                        "TUBEBUNDLE": "TubeBundle",
                        "UNITARYEQUIPMENT": "UnitaryEquipment",
                        "ELECTRICGENERATOR": "ElectricGenerator",
                        "ELECTRICMOTOR": "ElectricMotor",
                        "MOTORCONNECTION": "MotorConnection",
                        "SOLARDEVICE": "SolarDevice",
                        "TRANSFORMER": "Transformer",
                        "FLOWCONTROLLER": "FlowController",
                        "ELECTRICDISTRIBUTIONPOINT": "ElectricDistributionPoint",
                        "AIRTERMINALBOX": "AirTerminalBox",
                        "DAMPER": "Damper",
                        "FLOWMETER": "FlowMeter",
                        "VALVE": "Valve",
                        "ELECTRICDISTRIBUTIONBOARD": "ElectricDistributionBoard",
                        "ELECTRICTIMECONTROL": "ElectricTimeControl",
                        "PROTECTIVEDEVICE": "ProtectiveDevice",
                        "SWITCHINGDEVICE": "SwitchingDevice",
                        "FLOWFITTING": "FlowFitting",
                        "DUCTFITTING": "DuctFitting",
                        "PIPEFITTING": "PipeFitting",
                        "CABLECARRIERFITTING": "CableCarrierFitting",
                        "CABLEFITTING": "CableFitting",
                        "JUNCTIONBOX": "JunctionBox",
                        "FLOWMOVINGDEVICE": "FlowMovingDevice",
                        "COMPRESSOR": "Compressor",
                        "FAN": "Fan",
                        "PUMP": "Pump",
                        "FLOWSEGMENT": "FlowSegment",
                        "DUCTSEGMENT": "DuctSegment",
                        "PIPESEGMENT": "PipeSegment",
                        "CABLECARRIERSEGMENT": "CableCarrierSegment",
                        "CABLESEGMENT": "CableSegment",
                        "FLOWSTORAGEDEVICE": "FlowStorageDevice",
                        "TANK": "Tank",
                        "ELECTRICFLOWSTORAGEDEVICE": "ElectricFlowStorageDevice",
                        "FLOWTERMINAL": "FlowTerminal",
                        "FIRESUPPRESSIONTERMINAL": "FireSuppressionTerminal",
                        "SANITARYTERMINAL": "SanitaryTerminal",
                        "STACKTERMINAL": "StackTerminal",
                        "WASTETERMINAL": "WasteTerminal",
                        "AIRTERMINAL": "AirTerminal",
                        "MEDICALDEVICE": "MedicalDevice",
                        "SPACEHEATER": "SpaceHeater",
                        "AUDIOVISUALAPPLIANCE": "AudioVisualAppliance",
                        "COMMUNICATIONSAPPLIANCE": "CommunicationsAppliance",
                        "ELECTRICAPPLIANCE": "ElectricAppliance",
                        "LAMP": "Lamp",
                        "LIGHTFIXTURE": "LightFixture",
                        "OUTLET": "Outlet",
                        "FLOWTREATMENTDEVICE": "FlowTreatmentDevice",
                        "INTERCEPTOR": "Interceptor",
                        "DUCTSILENCER": "DuctSilencer",
                        "FILTER": "Filter",
                        "DISTRIBUTIONCONTROLELEMENT": "DistributionControlElement",
                        "PROTECTIVEDEVICETRIPPINGUNIT": "ProtectiveDeviceTrippingUnit",
                        "ACTUATOR": "Actuator",
                        "ALARM": "Alarm",
                        "CONTROLLER": "Controller",
                        "FLOWINSTRUMENT": "FlowInstrument",
                        "SENSOR": "Sensor",
                        "UNITARYCONTROLELEMENT": "UnitaryControlElement",
                        "ELEMENTCOMPONENT": "ElementComponent",
                        "DISCRETEACCESSORY": "DiscreteAccessory",
                        "FASTENER": "Fastener",
                        "MECHANICALFASTENER": "MechanicalFastener",
                        "REINFORCINGELEMENT": "ReinforcingElement",
                        "REINFORCINGBAR": "ReinforcingBar",
                        "REINFORCINGMESH": "ReinforcingMesh",
                        "TENDON": "Tendon",
                        "TENDONANCHOR": "TendonAnchor",
                        "BUILDINGELEMENTPART": "BuildingElementPart",
                        "VIBRATIONISOLATOR": "VibrationIsolator",
                        "FEATUREELEMENT": "FeatureElement",
                        "FEATUREELEMENTSUBTRACTION": "FeatureElementSubtraction",
                        "EDGEFEATURE": "EdgeFeature",
                        "CHAMFEREDGEFEATURE": "ChamferEdgeFeature",
                        "ROUNDEDEDGEFEATURE": "RoundedEdgeFeature",
                        "OPENINGELEMENT": "OpeningElement",
                        "OPENINGSTANDARDCASE": "OpeningStandardCase",
                        "VOIDINGFEATURE": "VoidingFeature",
                        "FEATUREELEMENTADDITION": "FeatureElementAddition",
                        "PROJECTIONELEMENT": "ProjectionElement",
                        "SURFACEFEATURE": "SurfaceFeature",
                        "BUILDINGELEMENT": "BuildingElement",
                        "BUILDINGELEMENTCOMPONENT": "BuildingElementComponent",
                        "FOOTING": "Footing",
                        "PILE": "Pile",
                        "BEAM": "Beam",
                        "BEAMSTANDARDCASE": "BeamStandardCase",
                        "COLUMN": "Column",
                        "COLUMNSTANDARDCASE": "ColumnStandardCase",
                        "CURTAINWALL": "CurtainWall",
                        "DOOR": "Door",
                        "DOORSTANDARDCASE": "DoorStandardCase",
                        "MEMBER": "Member",
                        "MEMBERSTANDARDCASE": "MemberStandardCase",
                        "PLATE": "Plate",
                        "PLATESTANDARDCASE": "PlateStandardCase",
                        "RAILING": "Railing",
                        "RAMP": "Ramp",
                        "RAMPFLIGHT": "RampFlight",
                        "ROOF": "Roof",
                        "SLAB": "Slab",
                        "SLABELEMENTEDCASE": "SlabElementedCase",
                        "SLABSTANDARDCASE": "SlabStandardCase",
                        "STAIR": "Stair",
                        "STAIRFLIGHT": "StairFlight",
                        "WALL": "Wall",
                        "WALLSTANDARDCASE": "WallStandardCase",
                        "WALLELEMENTEDCASE": "WallElementedCase",
                        "WINDOW": "Window",
                        "WINDOWSTANDARDCASE": "WindowStandardCase",
                        "BUILDINGELEMENTPROXY": "BuildingElementProxy",
                        "COVERING": "Covering",
                        "CHIMNEY": "Chimney",
                        "SHADINGDEVICE": "ShadingDevice",
                        "ELEMENTASSEMBLY": "ElementAssembly",
                        "FURNISHINGELEMENT": "FurnishingElement",
                        "FURNITURE": "Furniture",
                        "SYSTEMFURNITUREELEMENT": "SystemFurnitureElement",
                        "TRANSPORTELEMENT": "TransportElement",
                        "VIRTUALELEMENT": "VirtualElement",
                        "ELECTRICALELEMENT": "ElectricalElement",
                        "EQUIPMENTELEMENT": "EquipmentElement",
                        "CIVILELEMENT": "CivilElement",
                        "GEOGRAPHICELEMENT": "GeographicElement",
                        "PORT": "Port",
                        "DISTRIBUTIONPORT": "DistributionPort",
                        "PROXY": "Proxy",
                        "STRUCTURALACTIVITY": "StructuralActivity",
                        "STRUCTURALACTION": "StructuralAction",
                        "STRUCTURALLINEARACTION": "StructuralLinearAction",
                        "STRUCTURALLINEARACTIONVARYING": "StructuralLinearActionVarying",
                        "STRUCTURALPLANARACTION": "StructuralPlanarAction",
                        "STRUCTURALPLANARACTIONVARYING": "StructuralPlanarActionVarying",
                        "STRUCTURALPOINTACTION": "StructuralPointAction",
                        "STRUCTURALCURVEACTION": "StructuralCurveAction",
                        "STRUCTURALSURFACEACTION": "StructuralSurfaceAction",
                        "STRUCTURALREACTION": "StructuralReaction",
                        "STRUCTURALPOINTREACTION": "StructuralPointReaction",
                        "STRUCTURALCURVEREACTION": "StructuralCurveReaction",
                        "STRUCTURALSURFACEREACTION": "StructuralSurfaceReaction",
                        "STRUCTURALITEM": "StructuralItem",
                        "STRUCTURALCONNECTION": "StructuralConnection",
                        "STRUCTURALCURVECONNECTION": "StructuralCurveConnection",
                        "STRUCTURALPOINTCONNECTION": "StructuralPointConnection",
                        "STRUCTURALSURFACECONNECTION": "StructuralSurfaceConnection",
                        "STRUCTURALMEMBER": "StructuralMember",
                        "STRUCTURALCURVEMEMBER": "StructuralCurveMember",
                        "STRUCTURALCURVEMEMBERVARYING": "StructuralCurveMemberVarying",
                        "STRUCTURALSURFACEMEMBER": "StructuralSurfaceMember",
                        "STRUCTURALSURFACEMEMBERVARYING": "StructuralSurfaceMemberVarying",
                        "ANNOTATION": "Annotation",
                        "SPATIALSTRUCTUREELEMENT": "SpatialStructureElement",
                        "BUILDING": "Building",
                        "BUILDINGSTOREY": "BuildingStorey",
                        "SITE": "Site",
                        "SPACE": "Space",
                        "GRID": "Grid",
                        "SPATIALELEMENT": "SpatialElement",
                        "EXTERNALSPATIALSTRUCTUREELEMENT": "ExternalSpatialStructureElement",
                        "EXTERNALSPATIALELEMENT": "ExternalSpatialElement",
                        "SPATIALZONE": "SpatialZone",
                        "PERSON": "Person",
                        "DOCUMENT": "Document",
                        "DOORSTYLE": "DoorStyle",
                        "DOORTYPE": "DoorType",
                        "WALLTYPE": "WallType"
                    },
                    ('region',): {

                        "UK": "UK",
                        "WESTEUROPE": "WestEurope",
                        "SANDBOX": "Sandbox"
                    },
                    ('excluded',): {

                        "PRODUCT": "Product",
                        "ELEMENT": "Element",
                        "DISTRIBUTIONELEMENT": "DistributionElement",
                        "DISTRIBUTIONFLOWELEMENT": "DistributionFlowElement",
                        "DISTRIBUTIONCHAMBERELEMENT": "DistributionChamberElement",
                        "ENERGYCONVERSIONDEVICE": "EnergyConversionDevice",
                        "AIRTOAIRHEATRECOVERY": "AirToAirHeatRecovery",
                        "BOILER": "Boiler",
                        "BURNER": "Burner",
                        "CHILLER": "Chiller",
                        "COIL": "Coil",
                        "CONDENSER": "Condenser",
                        "COOLEDBEAM": "CooledBeam",
                        "COOLINGTOWER": "CoolingTower",
                        "ENGINE": "Engine",
                        "EVAPORATIVECOOLER": "EvaporativeCooler",
                        "EVAPORATOR": "Evaporator",
                        "HEATEXCHANGER": "HeatExchanger",
                        "HUMIDIFIER": "Humidifier",
                        "TUBEBUNDLE": "TubeBundle",
                        "UNITARYEQUIPMENT": "UnitaryEquipment",
                        "ELECTRICGENERATOR": "ElectricGenerator",
                        "ELECTRICMOTOR": "ElectricMotor",
                        "MOTORCONNECTION": "MotorConnection",
                        "SOLARDEVICE": "SolarDevice",
                        "TRANSFORMER": "Transformer",
                        "FLOWCONTROLLER": "FlowController",
                        "ELECTRICDISTRIBUTIONPOINT": "ElectricDistributionPoint",
                        "AIRTERMINALBOX": "AirTerminalBox",
                        "DAMPER": "Damper",
                        "FLOWMETER": "FlowMeter",
                        "VALVE": "Valve",
                        "ELECTRICDISTRIBUTIONBOARD": "ElectricDistributionBoard",
                        "ELECTRICTIMECONTROL": "ElectricTimeControl",
                        "PROTECTIVEDEVICE": "ProtectiveDevice",
                        "SWITCHINGDEVICE": "SwitchingDevice",
                        "FLOWFITTING": "FlowFitting",
                        "DUCTFITTING": "DuctFitting",
                        "PIPEFITTING": "PipeFitting",
                        "CABLECARRIERFITTING": "CableCarrierFitting",
                        "CABLEFITTING": "CableFitting",
                        "JUNCTIONBOX": "JunctionBox",
                        "FLOWMOVINGDEVICE": "FlowMovingDevice",
                        "COMPRESSOR": "Compressor",
                        "FAN": "Fan",
                        "PUMP": "Pump",
                        "FLOWSEGMENT": "FlowSegment",
                        "DUCTSEGMENT": "DuctSegment",
                        "PIPESEGMENT": "PipeSegment",
                        "CABLECARRIERSEGMENT": "CableCarrierSegment",
                        "CABLESEGMENT": "CableSegment",
                        "FLOWSTORAGEDEVICE": "FlowStorageDevice",
                        "TANK": "Tank",
                        "ELECTRICFLOWSTORAGEDEVICE": "ElectricFlowStorageDevice",
                        "FLOWTERMINAL": "FlowTerminal",
                        "FIRESUPPRESSIONTERMINAL": "FireSuppressionTerminal",
                        "SANITARYTERMINAL": "SanitaryTerminal",
                        "STACKTERMINAL": "StackTerminal",
                        "WASTETERMINAL": "WasteTerminal",
                        "AIRTERMINAL": "AirTerminal",
                        "MEDICALDEVICE": "MedicalDevice",
                        "SPACEHEATER": "SpaceHeater",
                        "AUDIOVISUALAPPLIANCE": "AudioVisualAppliance",
                        "COMMUNICATIONSAPPLIANCE": "CommunicationsAppliance",
                        "ELECTRICAPPLIANCE": "ElectricAppliance",
                        "LAMP": "Lamp",
                        "LIGHTFIXTURE": "LightFixture",
                        "OUTLET": "Outlet",
                        "FLOWTREATMENTDEVICE": "FlowTreatmentDevice",
                        "INTERCEPTOR": "Interceptor",
                        "DUCTSILENCER": "DuctSilencer",
                        "FILTER": "Filter",
                        "DISTRIBUTIONCONTROLELEMENT": "DistributionControlElement",
                        "PROTECTIVEDEVICETRIPPINGUNIT": "ProtectiveDeviceTrippingUnit",
                        "ACTUATOR": "Actuator",
                        "ALARM": "Alarm",
                        "CONTROLLER": "Controller",
                        "FLOWINSTRUMENT": "FlowInstrument",
                        "SENSOR": "Sensor",
                        "UNITARYCONTROLELEMENT": "UnitaryControlElement",
                        "ELEMENTCOMPONENT": "ElementComponent",
                        "DISCRETEACCESSORY": "DiscreteAccessory",
                        "FASTENER": "Fastener",
                        "MECHANICALFASTENER": "MechanicalFastener",
                        "REINFORCINGELEMENT": "ReinforcingElement",
                        "REINFORCINGBAR": "ReinforcingBar",
                        "REINFORCINGMESH": "ReinforcingMesh",
                        "TENDON": "Tendon",
                        "TENDONANCHOR": "TendonAnchor",
                        "BUILDINGELEMENTPART": "BuildingElementPart",
                        "VIBRATIONISOLATOR": "VibrationIsolator",
                        "FEATUREELEMENT": "FeatureElement",
                        "FEATUREELEMENTSUBTRACTION": "FeatureElementSubtraction",
                        "EDGEFEATURE": "EdgeFeature",
                        "CHAMFEREDGEFEATURE": "ChamferEdgeFeature",
                        "ROUNDEDEDGEFEATURE": "RoundedEdgeFeature",
                        "OPENINGELEMENT": "OpeningElement",
                        "OPENINGSTANDARDCASE": "OpeningStandardCase",
                        "VOIDINGFEATURE": "VoidingFeature",
                        "FEATUREELEMENTADDITION": "FeatureElementAddition",
                        "PROJECTIONELEMENT": "ProjectionElement",
                        "SURFACEFEATURE": "SurfaceFeature",
                        "BUILDINGELEMENT": "BuildingElement",
                        "BUILDINGELEMENTCOMPONENT": "BuildingElementComponent",
                        "FOOTING": "Footing",
                        "PILE": "Pile",
                        "BEAM": "Beam",
                        "BEAMSTANDARDCASE": "BeamStandardCase",
                        "COLUMN": "Column",
                        "COLUMNSTANDARDCASE": "ColumnStandardCase",
                        "CURTAINWALL": "CurtainWall",
                        "DOOR": "Door",
                        "DOORSTANDARDCASE": "DoorStandardCase",
                        "MEMBER": "Member",
                        "MEMBERSTANDARDCASE": "MemberStandardCase",
                        "PLATE": "Plate",
                        "PLATESTANDARDCASE": "PlateStandardCase",
                        "RAILING": "Railing",
                        "RAMP": "Ramp",
                        "RAMPFLIGHT": "RampFlight",
                        "ROOF": "Roof",
                        "SLAB": "Slab",
                        "SLABELEMENTEDCASE": "SlabElementedCase",
                        "SLABSTANDARDCASE": "SlabStandardCase",
                        "STAIR": "Stair",
                        "STAIRFLIGHT": "StairFlight",
                        "WALL": "Wall",
                        "WALLSTANDARDCASE": "WallStandardCase",
                        "WALLELEMENTEDCASE": "WallElementedCase",
                        "WINDOW": "Window",
                        "WINDOWSTANDARDCASE": "WindowStandardCase",
                        "BUILDINGELEMENTPROXY": "BuildingElementProxy",
                        "COVERING": "Covering",
                        "CHIMNEY": "Chimney",
                        "SHADINGDEVICE": "ShadingDevice",
                        "ELEMENTASSEMBLY": "ElementAssembly",
                        "FURNISHINGELEMENT": "FurnishingElement",
                        "FURNITURE": "Furniture",
                        "SYSTEMFURNITUREELEMENT": "SystemFurnitureElement",
                        "TRANSPORTELEMENT": "TransportElement",
                        "VIRTUALELEMENT": "VirtualElement",
                        "ELECTRICALELEMENT": "ElectricalElement",
                        "EQUIPMENTELEMENT": "EquipmentElement",
                        "CIVILELEMENT": "CivilElement",
                        "GEOGRAPHICELEMENT": "GeographicElement",
                        "PORT": "Port",
                        "DISTRIBUTIONPORT": "DistributionPort",
                        "PROXY": "Proxy",
                        "STRUCTURALACTIVITY": "StructuralActivity",
                        "STRUCTURALACTION": "StructuralAction",
                        "STRUCTURALLINEARACTION": "StructuralLinearAction",
                        "STRUCTURALLINEARACTIONVARYING": "StructuralLinearActionVarying",
                        "STRUCTURALPLANARACTION": "StructuralPlanarAction",
                        "STRUCTURALPLANARACTIONVARYING": "StructuralPlanarActionVarying",
                        "STRUCTURALPOINTACTION": "StructuralPointAction",
                        "STRUCTURALCURVEACTION": "StructuralCurveAction",
                        "STRUCTURALSURFACEACTION": "StructuralSurfaceAction",
                        "STRUCTURALREACTION": "StructuralReaction",
                        "STRUCTURALPOINTREACTION": "StructuralPointReaction",
                        "STRUCTURALCURVEREACTION": "StructuralCurveReaction",
                        "STRUCTURALSURFACEREACTION": "StructuralSurfaceReaction",
                        "STRUCTURALITEM": "StructuralItem",
                        "STRUCTURALCONNECTION": "StructuralConnection",
                        "STRUCTURALCURVECONNECTION": "StructuralCurveConnection",
                        "STRUCTURALPOINTCONNECTION": "StructuralPointConnection",
                        "STRUCTURALSURFACECONNECTION": "StructuralSurfaceConnection",
                        "STRUCTURALMEMBER": "StructuralMember",
                        "STRUCTURALCURVEMEMBER": "StructuralCurveMember",
                        "STRUCTURALCURVEMEMBERVARYING": "StructuralCurveMemberVarying",
                        "STRUCTURALSURFACEMEMBER": "StructuralSurfaceMember",
                        "STRUCTURALSURFACEMEMBERVARYING": "StructuralSurfaceMemberVarying",
                        "ANNOTATION": "Annotation",
                        "SPATIALSTRUCTUREELEMENT": "SpatialStructureElement",
                        "BUILDING": "Building",
                        "BUILDINGSTOREY": "BuildingStorey",
                        "SITE": "Site",
                        "SPACE": "Space",
                        "GRID": "Grid",
                        "SPATIALELEMENT": "SpatialElement",
                        "EXTERNALSPATIALSTRUCTUREELEMENT": "ExternalSpatialStructureElement",
                        "EXTERNALSPATIALELEMENT": "ExternalSpatialElement",
                        "SPATIALZONE": "SpatialZone",
                        "PERSON": "Person",
                        "DOCUMENT": "Document",
                        "DOORSTYLE": "DoorStyle",
                        "DOORTYPE": "DoorType",
                        "WALLTYPE": "WallType"
                    },
                },
                'openapi_types': {
                    'asset_id':
                        (int,),
                    'model_id':
                        (int,),
                    'included':
                        ([str],),
                    'tenant_id':
                        (str,),
                    'region':
                        (str,),
                    'excluded':
                        ([str],),
                },
                'attribute_map': {
                    'asset_id': 'assetId',
                    'model_id': 'modelId',
                    'included': 'included',
                    'tenant_id': 'tenantId',
                    'region': 'region',
                    'excluded': 'excluded',
                },
                'location_map': {
                    'asset_id': 'query',
                    'model_id': 'query',
                    'included': 'query',
                    'tenant_id': 'path',
                    'region': 'path',
                    'excluded': 'query',
                },
                'collection_format_map': {
                    'included': 'csv',
                    'excluded': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/json',
                    'text/json',
                    'application/xml',
                    'text/xml'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.wexbim_get_envelope_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'oauth2'
                ],
                'endpoint_path': "/{region}/aim/2.0/{tenantId}/wexbim/envelope",
                'operation_id': 'wexbim_get_envelope',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'asset_id',
                    'model_id',
                    'tenant_id',
                    'region',
                ],
                'required': [
                    'asset_id',
                    'model_id',
                    'tenant_id',
                    'region',
                ],
                'nullable': [
                ],
                'enum': [
                    'region',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('region',): {

                        "UK": "UK",
                        "WESTEUROPE": "WestEurope",
                        "SANDBOX": "Sandbox"
                    },
                },
                'openapi_types': {
                    'asset_id':
                        (int,),
                    'model_id':
                        (int,),
                    'tenant_id':
                        (str,),
                    'region':
                        (str,),
                },
                'attribute_map': {
                    'asset_id': 'assetId',
                    'model_id': 'modelId',
                    'tenant_id': 'tenantId',
                    'region': 'region',
                },
                'location_map': {
                    'asset_id': 'query',
                    'model_id': 'query',
                    'tenant_id': 'path',
                    'region': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/octet-stream'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.wexbim_get_envelope_cut_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'oauth2'
                ],
                'endpoint_path': "/{region}/aim/2.0/{tenantId}/wexbim/envelopecut",
                'operation_id': 'wexbim_get_envelope_cut',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'asset_id',
                    'model_id',
                    'bottom',
                    'top',
                    'tenant_id',
                    'region',
                ],
                'required': [
                    'asset_id',
                    'model_id',
                    'bottom',
                    'top',
                    'tenant_id',
                    'region',
                ],
                'nullable': [
                ],
                'enum': [
                    'region',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('region',): {

                        "UK": "UK",
                        "WESTEUROPE": "WestEurope",
                        "SANDBOX": "Sandbox"
                    },
                },
                'openapi_types': {
                    'asset_id':
                        (int,),
                    'model_id':
                        (int,),
                    'bottom':
                        (float,),
                    'top':
                        (float,),
                    'tenant_id':
                        (str,),
                    'region':
                        (str,),
                },
                'attribute_map': {
                    'asset_id': 'assetId',
                    'model_id': 'modelId',
                    'bottom': 'bottom',
                    'top': 'top',
                    'tenant_id': 'tenantId',
                    'region': 'region',
                },
                'location_map': {
                    'asset_id': 'query',
                    'model_id': 'query',
                    'bottom': 'query',
                    'top': 'query',
                    'tenant_id': 'path',
                    'region': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/octet-stream'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.wexbim_get_envelope_free_cut_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'oauth2'
                ],
                'endpoint_path': "/{region}/aim/2.0/{tenantId}/wexbim/envelopefreecut",
                'operation_id': 'wexbim_get_envelope_free_cut',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'asset_id',
                    'model_id',
                    'planes',
                    'tenant_id',
                    'region',
                ],
                'required': [
                    'asset_id',
                    'model_id',
                    'planes',
                    'tenant_id',
                    'region',
                ],
                'nullable': [
                ],
                'enum': [
                    'region',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('region',): {

                        "UK": "UK",
                        "WESTEUROPE": "WestEurope",
                        "SANDBOX": "Sandbox"
                    },
                },
                'openapi_types': {
                    'asset_id':
                        (int,),
                    'model_id':
                        (int,),
                    'planes':
                        ([float],),
                    'tenant_id':
                        (str,),
                    'region':
                        (str,),
                },
                'attribute_map': {
                    'asset_id': 'assetId',
                    'model_id': 'modelId',
                    'planes': 'planes',
                    'tenant_id': 'tenantId',
                    'region': 'region',
                },
                'location_map': {
                    'asset_id': 'query',
                    'model_id': 'query',
                    'planes': 'query',
                    'tenant_id': 'path',
                    'region': 'path',
                },
                'collection_format_map': {
                    'planes': 'csv',
                }
            },
            headers_map={
                'accept': [
                    'application/octet-stream'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.wexbim_get_site_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'oauth2'
                ],
                'endpoint_path': "/{region}/aim/2.0/{tenantId}/wexbim/site",
                'operation_id': 'wexbim_get_site',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'asset_id',
                    'model_id',
                    'tenant_id',
                    'region',
                ],
                'required': [
                    'asset_id',
                    'model_id',
                    'tenant_id',
                    'region',
                ],
                'nullable': [
                ],
                'enum': [
                    'region',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('region',): {

                        "UK": "UK",
                        "WESTEUROPE": "WestEurope",
                        "SANDBOX": "Sandbox"
                    },
                },
                'openapi_types': {
                    'asset_id':
                        (int,),
                    'model_id':
                        (int,),
                    'tenant_id':
                        (str,),
                    'region':
                        (str,),
                },
                'attribute_map': {
                    'asset_id': 'assetId',
                    'model_id': 'modelId',
                    'tenant_id': 'tenantId',
                    'region': 'region',
                },
                'location_map': {
                    'asset_id': 'query',
                    'model_id': 'query',
                    'tenant_id': 'path',
                    'region': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/octet-stream'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.wexbim_get_spatial_structure_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'oauth2'
                ],
                'endpoint_path': "/{region}/aim/2.0/{tenantId}/wexbim/spatial",
                'operation_id': 'wexbim_get_spatial_structure',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'asset_id',
                    'model_id',
                    'tenant_id',
                    'region',
                ],
                'required': [
                    'asset_id',
                    'model_id',
                    'tenant_id',
                    'region',
                ],
                'nullable': [
                ],
                'enum': [
                    'region',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('region',): {

                        "UK": "UK",
                        "WESTEUROPE": "WestEurope",
                        "SANDBOX": "Sandbox"
                    },
                },
                'openapi_types': {
                    'asset_id':
                        (int,),
                    'model_id':
                        (int,),
                    'tenant_id':
                        (str,),
                    'region':
                        (str,),
                },
                'attribute_map': {
                    'asset_id': 'assetId',
                    'model_id': 'modelId',
                    'tenant_id': 'tenantId',
                    'region': 'region',
                },
                'location_map': {
                    'asset_id': 'query',
                    'model_id': 'query',
                    'tenant_id': 'path',
                    'region': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/octet-stream'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.wexbim_get_windows_and_doors_endpoint = _Endpoint(
            settings={
                'response_type': (file_type,),
                'auth': [
                    'oauth2'
                ],
                'endpoint_path': "/{region}/aim/2.0/{tenantId}/wexbim/windowsdoors",
                'operation_id': 'wexbim_get_windows_and_doors',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'asset_id',
                    'model_id',
                    'tenant_id',
                    'region',
                ],
                'required': [
                    'asset_id',
                    'model_id',
                    'tenant_id',
                    'region',
                ],
                'nullable': [
                ],
                'enum': [
                    'region',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('region',): {

                        "UK": "UK",
                        "WESTEUROPE": "WestEurope",
                        "SANDBOX": "Sandbox"
                    },
                },
                'openapi_types': {
                    'asset_id':
                        (int,),
                    'model_id':
                        (int,),
                    'tenant_id':
                        (str,),
                    'region':
                        (str,),
                },
                'attribute_map': {
                    'asset_id': 'assetId',
                    'model_id': 'modelId',
                    'tenant_id': 'tenantId',
                    'region': 'region',
                },
                'location_map': {
                    'asset_id': 'query',
                    'model_id': 'query',
                    'tenant_id': 'path',
                    'region': 'path',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/octet-stream'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def wexbim_get_complete(
        self,
        asset_id,
        model_id,
        tenant_id,
        region="UK",
        **kwargs
    ):
        """Get Wexbim complete  # noqa: E501

        <span style='font-size: 17px;'>Summary</span><br/>Gets the pre-generated complete wexbim geometry stream for a model. Return Type: string <br/><br/>    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.wexbim_get_complete(asset_id, model_id, tenant_id, region="UK", async_req=True)
        >>> result = thread.get()

        Args:
            asset_id (int):
            model_id (int):
            tenant_id (str): The unique Tenant ID (UUID or Identifier string)
            region (str): The data center region the data resides in. defaults to "UK", must be one of ["UK"]

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['asset_id'] = \
            asset_id
        kwargs['model_id'] = \
            model_id
        kwargs['tenant_id'] = \
            tenant_id
        kwargs['region'] = \
            region
        return self.wexbim_get_complete_endpoint.call_with_http_info(**kwargs)

    def wexbim_get_components(
        self,
        asset_id,
        model_id,
        tenant_id,
        region="UK",
        **kwargs
    ):
        """Get Wexbim components  # noqa: E501

        <span style='font-size: 17px;'>Summary</span><br/>Gets the pre-generated components wexbim geometry stream for a model. E.g. Fixtures / Furniture, mechnical, electrical and engineering. Excludes the Envelope and Doors, windows and spaces. Return Type: string <br/><br/>    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.wexbim_get_components(asset_id, model_id, tenant_id, region="UK", async_req=True)
        >>> result = thread.get()

        Args:
            asset_id (int):
            model_id (int):
            tenant_id (str): The unique Tenant ID (UUID or Identifier string)
            region (str): The data center region the data resides in. defaults to "UK", must be one of ["UK"]

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['asset_id'] = \
            asset_id
        kwargs['model_id'] = \
            model_id
        kwargs['tenant_id'] = \
            tenant_id
        kwargs['region'] = \
            region
        return self.wexbim_get_components_endpoint.call_with_http_info(**kwargs)

    def wexbim_get_dynamic(
        self,
        asset_id,
        model_id,
        included,
        tenant_id,
        region="UK",
        **kwargs
    ):
        """Get Wexbim dynamic  # noqa: E501

        <span style='font-size: 17px;'>Summary</span><br/>Gets a dynamically generated geometry stream for a model. Return Type: string <br/><br/>    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.wexbim_get_dynamic(asset_id, model_id, included, tenant_id, region="UK", async_req=True)
        >>> result = thread.get()

        Args:
            asset_id (int): The id of asset the model belongs to
            model_id (int): The id of the model
            included ([str]): The IFC types to include (hierarchical)
            tenant_id (str): The unique Tenant ID (UUID or Identifier string)
            region (str): The data center region the data resides in. defaults to "UK", must be one of ["UK"]

        Keyword Args:
            excluded ([str]): The IFC types to exclude (hierarchical). [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['asset_id'] = \
            asset_id
        kwargs['model_id'] = \
            model_id
        kwargs['included'] = \
            included
        kwargs['tenant_id'] = \
            tenant_id
        kwargs['region'] = \
            region
        return self.wexbim_get_dynamic_endpoint.call_with_http_info(**kwargs)

    def wexbim_get_envelope(
        self,
        asset_id,
        model_id,
        tenant_id,
        region="UK",
        **kwargs
    ):
        """Get Wexbim envelope  # noqa: E501

        <span style='font-size: 17px;'>Summary</span><br/>Gets the pre-generated building envelope wexbim geometry stream for a model. E.g. The building fabric and external envelope. Return Type: string <br/><br/>    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.wexbim_get_envelope(asset_id, model_id, tenant_id, region="UK", async_req=True)
        >>> result = thread.get()

        Args:
            asset_id (int): The asset identifier.
            model_id (int): The model identifier.
            tenant_id (str): The unique Tenant ID (UUID or Identifier string)
            region (str): The data center region the data resides in. defaults to "UK", must be one of ["UK"]

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['asset_id'] = \
            asset_id
        kwargs['model_id'] = \
            model_id
        kwargs['tenant_id'] = \
            tenant_id
        kwargs['region'] = \
            region
        return self.wexbim_get_envelope_endpoint.call_with_http_info(**kwargs)

    def wexbim_get_envelope_cut(
        self,
        asset_id,
        model_id,
        bottom,
        top,
        tenant_id,
        region="UK",
        **kwargs
    ):
        """Get Wexbim envelope cut  # noqa: E501

        <span style='font-size: 17px;'>Summary</span><br/>Gets the building envelope geometry cut plane. This can be used to cap the holes after clipping.. Return Type: string <br/><br/>    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.wexbim_get_envelope_cut(asset_id, model_id, bottom, top, tenant_id, region="UK", async_req=True)
        >>> result = thread.get()

        Args:
            asset_id (int):
            model_id (int):
            bottom (float):
            top (float):
            tenant_id (str): The unique Tenant ID (UUID or Identifier string)
            region (str): The data center region the data resides in. defaults to "UK", must be one of ["UK"]

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['asset_id'] = \
            asset_id
        kwargs['model_id'] = \
            model_id
        kwargs['bottom'] = \
            bottom
        kwargs['top'] = \
            top
        kwargs['tenant_id'] = \
            tenant_id
        kwargs['region'] = \
            region
        return self.wexbim_get_envelope_cut_endpoint.call_with_http_info(**kwargs)

    def wexbim_get_envelope_free_cut(
        self,
        asset_id,
        model_id,
        planes,
        tenant_id,
        region="UK",
        **kwargs
    ):
        """Get Wexbim envelope free cut  # noqa: E501

        <span style='font-size: 17px;'>Summary</span><br/>Gets the a cutplane across the envelope for up to 6 cut planes.. Used to cap voids in the envelope when employing sections / section boxes. Return Type: string <br/><br/>    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.wexbim_get_envelope_free_cut(asset_id, model_id, planes, tenant_id, region="UK", async_req=True)
        >>> result = thread.get()

        Args:
            asset_id (int):
            model_id (int):
            planes ([float]):
            tenant_id (str): The unique Tenant ID (UUID or Identifier string)
            region (str): The data center region the data resides in. defaults to "UK", must be one of ["UK"]

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['asset_id'] = \
            asset_id
        kwargs['model_id'] = \
            model_id
        kwargs['planes'] = \
            planes
        kwargs['tenant_id'] = \
            tenant_id
        kwargs['region'] = \
            region
        return self.wexbim_get_envelope_free_cut_endpoint.call_with_http_info(**kwargs)

    def wexbim_get_site(
        self,
        asset_id,
        model_id,
        tenant_id,
        region="UK",
        **kwargs
    ):
        """Get Wexbim site  # noqa: E501

        <span style='font-size: 17px;'>Summary</span><br/>Gets the pre-generated Site wexbim geometry stream for a model. E.g. The building fabric and external envelope. Return Type: string <br/><br/>    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.wexbim_get_site(asset_id, model_id, tenant_id, region="UK", async_req=True)
        >>> result = thread.get()

        Args:
            asset_id (int): The asset identifier.
            model_id (int): The model identifier.
            tenant_id (str): The unique Tenant ID (UUID or Identifier string)
            region (str): The data center region the data resides in. defaults to "UK", must be one of ["UK"]

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['asset_id'] = \
            asset_id
        kwargs['model_id'] = \
            model_id
        kwargs['tenant_id'] = \
            tenant_id
        kwargs['region'] = \
            region
        return self.wexbim_get_site_endpoint.call_with_http_info(**kwargs)

    def wexbim_get_spatial_structure(
        self,
        asset_id,
        model_id,
        tenant_id,
        region="UK",
        **kwargs
    ):
        """Get Wexbim spatial structure  # noqa: E501

        <span style='font-size: 17px;'>Summary</span><br/>Gets the pre-generated spatial wexbim geometry stream for a model. E.g. The Site, Zones, Spaces in a Facility. Return Type: string <br/><br/>    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.wexbim_get_spatial_structure(asset_id, model_id, tenant_id, region="UK", async_req=True)
        >>> result = thread.get()

        Args:
            asset_id (int): Asset ID
            model_id (int): Model ID
            tenant_id (str): The unique Tenant ID (UUID or Identifier string)
            region (str): The data center region the data resides in. defaults to "UK", must be one of ["UK"]

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['asset_id'] = \
            asset_id
        kwargs['model_id'] = \
            model_id
        kwargs['tenant_id'] = \
            tenant_id
        kwargs['region'] = \
            region
        return self.wexbim_get_spatial_structure_endpoint.call_with_http_info(**kwargs)

    def wexbim_get_windows_and_doors(
        self,
        asset_id,
        model_id,
        tenant_id,
        region="UK",
        **kwargs
    ):
        """Get Wexbim windows and doors  # noqa: E501

        <span style='font-size: 17px;'>Summary</span><br/>Gets the pre-generated doors/windows wexbim geometry stream for a model. E.g. The building fabric and external envelope. Return Type: string <br/><br/>    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.wexbim_get_windows_and_doors(asset_id, model_id, tenant_id, region="UK", async_req=True)
        >>> result = thread.get()

        Args:
            asset_id (int):
            model_id (int):
            tenant_id (str): The unique Tenant ID (UUID or Identifier string)
            region (str): The data center region the data resides in. defaults to "UK", must be one of ["UK"]

        Keyword Args:
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            file_type
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['asset_id'] = \
            asset_id
        kwargs['model_id'] = \
            model_id
        kwargs['tenant_id'] = \
            tenant_id
        kwargs['region'] = \
            region
        return self.wexbim_get_windows_and_doors_endpoint.call_with_http_info(**kwargs)




"""
    XBIM Flex API v2

    This is the XBIM Flex Swagger service where you can explore the REST API for the platform.  # noqa: E501

    The version of the OpenAPI document: 2.0
    Contact: info@xbim.net
    Generated by: https://openapi-generator.tech
"""


import re  # noqa: F401
import sys  # noqa: F401

from xbim_flex.aim.api_client import ApiClient, Endpoint as _Endpoint
from xbim_flex.aim.model_utils import (  # noqa: F401
    check_allowed_values,
    check_validations,
    date,
    datetime,
    file_type,
    none_type,
    validate_and_convert_types
)
from xbim_flex.aim.model.application import Application
from xbim_flex.aim.model.o_data_list_response_of_application import ODataListResponseOfApplication


class ApplicationsApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client
        self.applications_get_by_tenantid_endpoint = _Endpoint(
            settings={
                'response_type': (ODataListResponseOfApplication,),
                'auth': [
                    'oauth2'
                ],
                'endpoint_path': "/{region}/aim/2.0/{tenantId}/Applications",
                'operation_id': 'applications_get_by_tenantid',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'tenant_id',
                    'region',
                    'expand',
                    'filter',
                    'select',
                    'orderby',
                    'top',
                    'skip',
                    'count',
                ],
                'required': [
                    'tenant_id',
                    'region',
                ],
                'nullable': [
                ],
                'enum': [
                    'region',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('region',): {

                        "UK": "UK",
                        "WESTEUROPE": "WestEurope",
                        "SANDBOX": "Sandbox"
                    },
                },
                'openapi_types': {
                    'tenant_id':
                        (str,),
                    'region':
                        (str,),
                    'expand':
                        (str,),
                    'filter':
                        (str,),
                    'select':
                        (str,),
                    'orderby':
                        (str,),
                    'top':
                        (int,),
                    'skip':
                        (int,),
                    'count':
                        (bool,),
                },
                'attribute_map': {
                    'tenant_id': 'tenantId',
                    'region': 'region',
                    'expand': '$expand',
                    'filter': '$filter',
                    'select': '$select',
                    'orderby': '$orderby',
                    'top': '$top',
                    'skip': '$skip',
                    'count': '$count',
                },
                'location_map': {
                    'tenant_id': 'path',
                    'region': 'path',
                    'expand': 'query',
                    'filter': 'query',
                    'select': 'query',
                    'orderby': 'query',
                    'top': 'query',
                    'skip': 'query',
                    'count': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json',
                    'application/json;odata.metadata=none',
                    'application/json;odata.metadata=minimal',
                    'application/json;odata.metadata=full',
                    'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet'
                ],
                'content_type': [],
            },
            api_client=api_client
        )
        self.applications_get_single_by_applicationid_and_tenantid_endpoint = _Endpoint(
            settings={
                'response_type': (Application,),
                'auth': [
                    'oauth2'
                ],
                'endpoint_path': "/{region}/aim/2.0/{tenantId}/Applications({ApplicationId})",
                'operation_id': 'applications_get_single_by_applicationid_and_tenantid',
                'http_method': 'GET',
                'servers': None,
            },
            params_map={
                'all': [
                    'application_id',
                    'tenant_id',
                    'region',
                    'expand',
                    'select',
                ],
                'required': [
                    'application_id',
                    'tenant_id',
                    'region',
                ],
                'nullable': [
                ],
                'enum': [
                    'region',
                ],
                'validation': [
                ]
            },
            root_map={
                'validations': {
                },
                'allowed_values': {
                    ('region',): {

                        "UK": "UK",
                        "WESTEUROPE": "WestEurope",
                        "SANDBOX": "Sandbox"
                    },
                },
                'openapi_types': {
                    'application_id':
                        (int,),
                    'tenant_id':
                        (str,),
                    'region':
                        (str,),
                    'expand':
                        (str,),
                    'select':
                        (str,),
                },
                'attribute_map': {
                    'application_id': 'ApplicationId',
                    'tenant_id': 'tenantId',
                    'region': 'region',
                    'expand': '$expand',
                    'select': '$select',
                },
                'location_map': {
                    'application_id': 'path',
                    'tenant_id': 'path',
                    'region': 'path',
                    'expand': 'query',
                    'select': 'query',
                },
                'collection_format_map': {
                }
            },
            headers_map={
                'accept': [
                    'application/json',
                    'application/json;odata.metadata=none',
                    'application/json;odata.metadata=minimal',
                    'application/json;odata.metadata=full'
                ],
                'content_type': [],
            },
            api_client=api_client
        )

    def applications_get_by_tenantid(
        self,
        tenant_id,
        region="UK",
        **kwargs
    ):
        """Get Applications by tenantid  # noqa: E501

        <span style='font-size: 17px;'>Summary</span><br/>Returns the EntitySet Applications. Return Type: ODataListResponseOfApplication For more information about OData responses <a href='https://www.odata.org/getting-started/understand-odata-in-6-steps/'>link</a>. <br/><br/>    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.applications_get_by_tenantid(tenant_id, region="UK", async_req=True)
        >>> result = thread.get()

        Args:
            tenant_id (str): The unique Tenant ID (UUID or Identifier string)
            region (str): The data center region the data resides in. defaults to "UK", must be one of ["UK"]

        Keyword Args:
            expand (str): Expands related entities inline.. [optional]
            filter (str): Filters the results, based on a Boolean condition.. [optional]
            select (str): Selects which properties to include in the response.. [optional]
            orderby (str): Sorts the results.. [optional]
            top (int): Returns only the first n results.. [optional]
            skip (int): Skips the first n results.. [optional]
            count (bool): Includes a count of the matching results in the response.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            ODataListResponseOfApplication
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['tenant_id'] = \
            tenant_id
        kwargs['region'] = \
            region
        return self.applications_get_by_tenantid_endpoint.call_with_http_info(**kwargs)

    def applications_get_single_by_applicationid_and_tenantid(
        self,
        application_id,
        tenant_id,
        region="UK",
        **kwargs
    ):
        """Get Applications single by applicationid and tenantid  # noqa: E501

        <span style='font-size: 17px;'>Summary</span><br/>Returns the entity with the key from Applications. Return Type: Application <br/><br/>    # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True

        >>> thread = api.applications_get_single_by_applicationid_and_tenantid(application_id, tenant_id, region="UK", async_req=True)
        >>> result = thread.get()

        Args:
            application_id (int): key: ApplicationId
            tenant_id (str): The unique Tenant ID (UUID or Identifier string)
            region (str): The data center region the data resides in. defaults to "UK", must be one of ["UK"]

        Keyword Args:
            expand (str): Expands related entities inline.. [optional]
            select (str): Selects which properties to include in the response.. [optional]
            _return_http_data_only (bool): response data without head status
                code and headers. Default is True.
            _preload_content (bool): if False, the urllib3.HTTPResponse object
                will be returned without reading/decoding response data.
                Default is True.
            _request_timeout (int/float/tuple): timeout setting for this request. If
                one number provided, it will be total request timeout. It can also
                be a pair (tuple) of (connection, read) timeouts.
                Default is None.
            _check_input_type (bool): specifies if type checking
                should be done one the data sent to the server.
                Default is True.
            _check_return_type (bool): specifies if type checking
                should be done one the data received from the server.
                Default is True.
            _host_index (int/None): specifies the index of the server
                that we want to use.
                Default is read from the configuration.
            async_req (bool): execute request asynchronously

        Returns:
            Application
                If the method is called asynchronously, returns the request
                thread.
        """
        kwargs['async_req'] = kwargs.get(
            'async_req', False
        )
        kwargs['_return_http_data_only'] = kwargs.get(
            '_return_http_data_only', True
        )
        kwargs['_preload_content'] = kwargs.get(
            '_preload_content', True
        )
        kwargs['_request_timeout'] = kwargs.get(
            '_request_timeout', None
        )
        kwargs['_check_input_type'] = kwargs.get(
            '_check_input_type', True
        )
        kwargs['_check_return_type'] = kwargs.get(
            '_check_return_type', True
        )
        kwargs['_host_index'] = kwargs.get('_host_index')
        kwargs['application_id'] = \
            application_id
        kwargs['tenant_id'] = \
            tenant_id
        kwargs['region'] = \
            region
        return self.applications_get_single_by_applicationid_and_tenantid_endpoint.call_with_http_info(**kwargs)




# flake8: noqa

# import all models into this package
# if you have many models here with many references from one model to another this may
# raise a RecursionError
# to avoid this, import only the models that you directly need like:
# from from xbim_flex.aim.model.pet import Pet
# or import this package, but before doing it, use:
# import sys
# sys.setrecursionlimit(n)

from xbim_flex.aim.model.application import Application
from xbim_flex.aim.model.assembly_diagnostics import AssemblyDiagnostics
from xbim_flex.aim.model.assembly_info import AssemblyInfo
from xbim_flex.aim.model.assembly_item import AssemblyItem
from xbim_flex.aim.model.asset import Asset
from xbim_flex.aim.model.asset_create import AssetCreate
from xbim_flex.aim.model.asset_edit import AssetEdit
from xbim_flex.aim.model.asset_segment import AssetSegment
from xbim_flex.aim.model.attribute_definition import AttributeDefinition
from xbim_flex.aim.model.attribute_definition_create import AttributeDefinitionCreate
from xbim_flex.aim.model.attribute_definition_edit import AttributeDefinitionEdit
from xbim_flex.aim.model.attribute_definition_entity import AttributeDefinitionEntity
from xbim_flex.aim.model.attribute_value import AttributeValue
from xbim_flex.aim.model.attribute_value_entity import AttributeValueEntity
from xbim_flex.aim.model.cell import Cell
from xbim_flex.aim.model.classification_node import ClassificationNode
from xbim_flex.aim.model.column_definition import ColumnDefinition
from xbim_flex.aim.model.complex_value_base import ComplexValueBase
from xbim_flex.aim.model.component import Component
from xbim_flex.aim.model.component_create import ComponentCreate
from xbim_flex.aim.model.component_edit import ComponentEdit
from xbim_flex.aim.model.component_info import ComponentInfo
from xbim_flex.aim.model.component_type import ComponentType
from xbim_flex.aim.model.component_type_info import ComponentTypeInfo
from xbim_flex.aim.model.contact import Contact
from xbim_flex.aim.model.contact_entity import ContactEntity
from xbim_flex.aim.model.contact_info import ContactInfo
from xbim_flex.aim.model.db_update import DbUpdate
from xbim_flex.aim.model.document import Document
from xbim_flex.aim.model.document_create import DocumentCreate
from xbim_flex.aim.model.document_edit import DocumentEdit
from xbim_flex.aim.model.document_info import DocumentInfo
from xbim_flex.aim.model.entity import Entity
from xbim_flex.aim.model.entity_base import EntityBase
from xbim_flex.aim.model.entity_contact import EntityContact
from xbim_flex.aim.model.entity_create import EntityCreate
from xbim_flex.aim.model.entity_edit import EntityEdit
from xbim_flex.aim.model.entity_mapping_info import EntityMappingInfo
from xbim_flex.aim.model.entity_match_descriptor import EntityMatchDescriptor
from xbim_flex.aim.model.entity_match_info import EntityMatchInfo
from xbim_flex.aim.model.entity_ref import EntityRef
from xbim_flex.aim.model.facility import Facility
from xbim_flex.aim.model.facility_info import FacilityInfo
from xbim_flex.aim.model.file_upload_result import FileUploadResult
from xbim_flex.aim.model.footprint import Footprint
from xbim_flex.aim.model.i_metered_resource import IMeteredResource
from xbim_flex.aim.model.ifc_type import IfcType
from xbim_flex.aim.model.inline_object import InlineObject
from xbim_flex.aim.model.inline_object1 import InlineObject1
from xbim_flex.aim.model.inline_object2 import InlineObject2
from xbim_flex.aim.model.inline_object3 import InlineObject3
from xbim_flex.aim.model.inline_object4 import InlineObject4
from xbim_flex.aim.model.inline_object5 import InlineObject5
from xbim_flex.aim.model.issue import Issue
from xbim_flex.aim.model.issue_info import IssueInfo
from xbim_flex.aim.model.job import Job
from xbim_flex.aim.model.job_create import JobCreate
from xbim_flex.aim.model.job_edit import JobEdit
from xbim_flex.aim.model.job_info import JobInfo
from xbim_flex.aim.model.level import Level
from xbim_flex.aim.model.level_create import LevelCreate
from xbim_flex.aim.model.level_edit import LevelEdit
from xbim_flex.aim.model.level_info import LevelInfo
from xbim_flex.aim.model.mapping_message_info import MappingMessageInfo
from xbim_flex.aim.model.mapping_properties import MappingProperties
from xbim_flex.aim.model.member_permission import MemberPermission
from xbim_flex.aim.model.member_role import MemberRole
from xbim_flex.aim.model.model import Model
from xbim_flex.aim.model.model_create import ModelCreate
from xbim_flex.aim.model.model_edit import ModelEdit
from xbim_flex.aim.model.model_info import ModelInfo
from xbim_flex.aim.model.model_mapping import ModelMapping
from xbim_flex.aim.model.model_mapping_report import ModelMappingReport
from xbim_flex.aim.model.o_data_list_response_of_application import ODataListResponseOfApplication
from xbim_flex.aim.model.o_data_list_response_of_assembly_diagnostics import ODataListResponseOfAssemblyDiagnostics
from xbim_flex.aim.model.o_data_list_response_of_assembly_item import ODataListResponseOfAssemblyItem
from xbim_flex.aim.model.o_data_list_response_of_asset import ODataListResponseOfAsset
from xbim_flex.aim.model.o_data_list_response_of_attribute_definition import ODataListResponseOfAttributeDefinition
from xbim_flex.aim.model.o_data_list_response_of_attribute_definition_entity import ODataListResponseOfAttributeDefinitionEntity
from xbim_flex.aim.model.o_data_list_response_of_attribute_value import ODataListResponseOfAttributeValue
from xbim_flex.aim.model.o_data_list_response_of_complex_value_base import ODataListResponseOfComplexValueBase
from xbim_flex.aim.model.o_data_list_response_of_component import ODataListResponseOfComponent
from xbim_flex.aim.model.o_data_list_response_of_component_type import ODataListResponseOfComponentType
from xbim_flex.aim.model.o_data_list_response_of_contact import ODataListResponseOfContact
from xbim_flex.aim.model.o_data_list_response_of_document import ODataListResponseOfDocument
from xbim_flex.aim.model.o_data_list_response_of_entity import ODataListResponseOfEntity
from xbim_flex.aim.model.o_data_list_response_of_entity_ref import ODataListResponseOfEntityRef
from xbim_flex.aim.model.o_data_list_response_of_facility import ODataListResponseOfFacility
from xbim_flex.aim.model.o_data_list_response_of_issue import ODataListResponseOfIssue
from xbim_flex.aim.model.o_data_list_response_of_job import ODataListResponseOfJob
from xbim_flex.aim.model.o_data_list_response_of_level import ODataListResponseOfLevel
from xbim_flex.aim.model.o_data_list_response_of_member_permission import ODataListResponseOfMemberPermission
from xbim_flex.aim.model.o_data_list_response_of_model import ODataListResponseOfModel
from xbim_flex.aim.model.o_data_list_response_of_model_mapping import ODataListResponseOfModelMapping
from xbim_flex.aim.model.o_data_list_response_of_model_mapping_report import ODataListResponseOfModelMappingReport
from xbim_flex.aim.model.o_data_list_response_of_resource import ODataListResponseOfResource
from xbim_flex.aim.model.o_data_list_response_of_role import ODataListResponseOfRole
from xbim_flex.aim.model.o_data_list_response_of_row import ODataListResponseOfRow
from xbim_flex.aim.model.o_data_list_response_of_schedule import ODataListResponseOfSchedule
from xbim_flex.aim.model.o_data_list_response_of_site import ODataListResponseOfSite
from xbim_flex.aim.model.o_data_list_response_of_space import ODataListResponseOfSpace
from xbim_flex.aim.model.o_data_list_response_of_spare import ODataListResponseOfSpare
from xbim_flex.aim.model.o_data_list_response_of_system_item import ODataListResponseOfSystemItem
from xbim_flex.aim.model.o_data_list_response_of_zone import ODataListResponseOfZone
from xbim_flex.aim.model.o_data_response_of_boolean import ODataResponseOfBoolean
from xbim_flex.aim.model.quota_status import QuotaStatus
from xbim_flex.aim.model.related_entity import RelatedEntity
from xbim_flex.aim.model.resource import Resource
from xbim_flex.aim.model.resource_info import ResourceInfo
from xbim_flex.aim.model.role import Role
from xbim_flex.aim.model.role_member import RoleMember
from xbim_flex.aim.model.row import Row
from xbim_flex.aim.model.schedule import Schedule
from xbim_flex.aim.model.site import Site
from xbim_flex.aim.model.space import Space
from xbim_flex.aim.model.space_create import SpaceCreate
from xbim_flex.aim.model.space_edit import SpaceEdit
from xbim_flex.aim.model.space_info import SpaceInfo
from xbim_flex.aim.model.spare import Spare
from xbim_flex.aim.model.spare_create import SpareCreate
from xbim_flex.aim.model.spare_edit import SpareEdit
from xbim_flex.aim.model.spare_info import SpareInfo
from xbim_flex.aim.model.system_info import SystemInfo
from xbim_flex.aim.model.system_item import SystemItem
from xbim_flex.aim.model.user_permissions import UserPermissions
from xbim_flex.aim.model.value_container import ValueContainer
from xbim_flex.aim.model.zone import Zone
from xbim_flex.aim.model.zone_info import ZoneInfo
